package com.example.smartlab11

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.viewModels
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.smartlab11.API.RepositoryImpl
import com.example.smartlab11.API.RetrofitInstance
import com.example.smartlab11.API.ViewModelMain
import com.example.smartlab11.Screens.CodeFromEmail
import com.example.smartlab11.Screens.EmailScreen
import com.example.smartlab11.Screens.FirstList
import com.example.smartlab11.Screens.Onboard1
import com.example.smartlab11.Screens.Onboard2
import com.example.smartlab11.Screens.Onboard3
import com.example.smartlab11.ui.theme.SmartLab11Theme


class MainActivity : ComponentActivity() {
    private val viewModelSmart by viewModels<ViewModelMain>(factoryProducer = {
        object : ViewModelProvider.Factory {
            override fun <T : ViewModel> create(modelClass: Class<T>): T {
                return ViewModelMain(RepositoryImpl(RetrofitInstance.apiSmartLab))
                        as T
            }
        }
    })

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            SmartLab11Theme {
                Surface(
                    color = MaterialTheme.colorScheme.background
                ) {
                    val navController = rememberNavController()

                    NavHost(
                        navController = navController,
                        startDestination = "FirstScreen"
                    ) {
                        composable("FirstScreen") {
                            FirstList(navController)
                        }
                        composable("OnboardOne") {
                            Onboard1(navController)
                        }
                        composable("OnboardTwo") {
                            Onboard2(navController)
                        }

                        composable("OnboardThree") {
                            Onboard3(navController)
                        }
                        composable("LogScreen") {
                            EmailScreen(navController, viewModelSmart)
                        }
                        composable("EnterCodeScreen") {
                            CodeFromEmail(navController)
                        }
                        composable("LogScreen") {
                            EmailScreen(navController, viewModelSmart)
                        }
                    }
                }
            }
        }
    }
}
